@@ -35,7 +35,7 @@ public:
      *
      * @param selected Should the item be selected
      * @param item The parent item */
-    explicit GameItem(bool selected, QGraphicsObject * item = 0);
+    explicit GameItem(bool selected, QGraphicsObject * item = nullptr);
     ~GameItem() override;
 
     /**
@@ -135,7 +135,7 @@ public:
      */
     void prepareForGeometryChange();
 
-public slots:
+public Q_SLOTS:
     /**
      * Fade in the item. */
     void fadeIn();
