@@ -17,11 +17,11 @@
 
 // Qt
 #include <QMouseEvent>
+#include <QRandomGenerator>
 #include <QResizeEvent>
 
 // KDE
 #include <KLocalizedString>
-#include <KRandom>
 
 // KMahjongg
 #include "demoanimation.h"
@@ -183,7 +183,7 @@ bool GameView::redo()
 
         // Test whether the game is over or not.
         if (m_gameData->m_tileNum == 0) {
-            emit gameOver(m_gameData->m_maxTileNum, m_cheatsUsed);
+            Q_EMIT gameOver(m_gameData->m_maxTileNum, m_cheatsUsed);
         } else {
             // The game is not over, so test if there are any valid moves.
             validMovesAvailable();
@@ -200,7 +200,7 @@ void GameView::demoGameOver(bool won)
         startMoveListAnimation();
     } else {
         setStatusText(i18n("Your computer has lost the game."));
-        emit demoOrMoveListAnimationOver(true);
+        Q_EMIT demoOrMoveListAnimationOver(true);
     }
 }
 
@@ -218,14 +218,14 @@ void GameView::createNewGame(long gameNumber)
 
     // Create a random game number, if no one was given.
     if (gameNumber == -1) {
-        m_gameNumber = KRandom::random();
+        m_gameNumber = QRandomGenerator::global()->generate();
     } else {
         m_gameNumber = gameNumber;
     }
 
     m_gameData->m_allowUndo = 0;
     m_gameData->m_allowRedo = 0;
-    m_gameData->random.setSeed(m_gameNumber);
+    m_gameData->random.seed(m_gameNumber);
 
     // Translate m_pGameData->Map to an array of POSITION data.  We only need to
     // do this once for each new game.
@@ -259,7 +259,8 @@ void GameView::createNewGame(long gameNumber)
     m_gameGenerated = false;
 
     // Hide all generated tiles.
-    foreach (GameItem * item, getGameItems()) {
+    const QList<GameItem *> gameItems = getGameItems();
+    for (GameItem * item : gameItems) {
         item->hide();
     }
 
@@ -314,7 +315,7 @@ void GameView::selectionChanged()
 
             // Test whether the game is over or not.
             if (m_gameData->m_tileNum == 0) {
-                emit gameOver(m_gameData->m_maxTileNum, m_cheatsUsed);
+                Q_EMIT gameOver(m_gameData->m_maxTileNum, m_cheatsUsed);
             } else {
                 // The game is not over, so test if there are any valid moves.
                 validMovesAvailable();
@@ -489,7 +490,7 @@ bool GameView::validMovesAvailable(bool silent)
 
     if (!m_gameData->findMove(stItem1, stItem2)) {
         if (!silent) {
-            emit noMovesAvailable();
+            Q_EMIT noMovesAvailable();
         }
         return false;
     }
@@ -498,12 +499,13 @@ bool GameView::validMovesAvailable(bool silent)
 
 void GameView::pause(bool isPaused)
 {
+    const QList<GameItem *> gameItems = getGameItems();
     if (isPaused) {
-        foreach (GameItem * item, getGameItems()) {
+        for (GameItem * item : gameItems) {
             item->hide();
         }
     } else {
-        foreach (GameItem * item, getGameItems()) {
+        for (GameItem * item : gameItems) {
             item->show();
         }
     }
@@ -550,7 +552,7 @@ void GameView::populateItemNumber()
     // Update the allow_undo variable, cause the item number changes.
     m_gameData->m_allowUndo = (m_gameData->m_maxTileNum != m_gameData->m_tileNum);
 
-    emit itemNumberChanged(m_gameData->m_maxTileNum, m_gameData->m_tileNum, m_gameData->moveCount());
+    Q_EMIT itemNumberChanged(m_gameData->m_maxTileNum, m_gameData->m_tileNum, m_gameData->moveCount());
 }
 
 void GameView::addItemsFromBoardLayout()
@@ -934,13 +936,13 @@ void GameView::mousePressEvent(QMouseEvent * pMouseEvent)
 {
     // If a move list animation is running start a new game.
     if (checkMoveListAnimationActive(true)) {
-        emit demoOrMoveListAnimationOver(false);
+        Q_EMIT demoOrMoveListAnimationOver(false);
         return;
     }
 
     // No mouse events when the demo mode is active.
     if (checkDemoAnimationActive(true)) {
-        emit demoOrMoveListAnimationOver(false);
+        Q_EMIT demoOrMoveListAnimationOver(false);
         return;
     }
 
@@ -953,7 +955,7 @@ void GameView::mousePressEvent(QMouseEvent * pMouseEvent)
 
 void GameView::resizeEvent(QResizeEvent * event)
 {
-    if (event->spontaneous() || m_gameData == 0) {
+    if (event->spontaneous() || m_gameData == nullptr) {
         return;
     }
 
@@ -987,7 +989,7 @@ void GameView::resizeEvent(QResizeEvent * event)
 
 void GameView::resizeTileset(const QSize & size)
 {
-    if (m_gameData == 0) {
+    if (m_gameData == nullptr) {
         return;
     }
 
@@ -995,7 +997,8 @@ void GameView::resizeTileset(const QSize & size)
         size, m_gameData->m_width / 2, m_gameData->m_height / 2
     );
 
-    foreach (GameItem * item, getGameItems()) {
+    const QList<GameItem *> gameItems = getGameItems();
+    for (GameItem * item : gameItems) {
         item->prepareForGeometryChange();
     }
 
@@ -1036,7 +1039,7 @@ void GameView::updateItemsImages(const QList<GameItem *> &gameItems)
 
 void GameView::setStatusText(QString const & text)
 {
-    emit statusTextChanged(text, m_gameNumber);
+    Q_EMIT statusTextChanged(text, m_gameNumber);
 }
 
 void GameView::updateBackground()
